# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.user_service_account_credentials import UserServiceAccountCredentials

class TestUserServiceAccountCredentials(unittest.TestCase):
    """UserServiceAccountCredentials unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserServiceAccountCredentials:
        """Test UserServiceAccountCredentials
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserServiceAccountCredentials`
        """
        model = UserServiceAccountCredentials()
        if include_optional:
            return UserServiceAccountCredentials(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                organization_id = '',
                id = '',
                first_name = '',
                last_name = '',
                email = '',
                picture = '',
                user_type = 'user',
                data_plane_id = '',
                client_id = '',
                organization_name = '',
                credentials = arthur_client.api_bindings.models.service_account_credentials.ServiceAccountCredentials(
                    client_id = '', 
                    client_secret = '', )
            )
        else:
            return UserServiceAccountCredentials(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                organization_id = '',
                id = '',
                first_name = '',
                last_name = '',
                user_type = 'user',
                organization_name = '',
                credentials = arthur_client.api_bindings.models.service_account_credentials.ServiceAccountCredentials(
                    client_id = '', 
                    client_secret = '', ),
        )
        """

    def testUserServiceAccountCredentials(self):
        """Test UserServiceAccountCredentials"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
